@@ -1774,8 +1774,8 @@ def line04(df, parameterx, parametery, std_method, gap, title):
     plt.show()
 
 
-# networks - show relationship between different entities
-def network01(df, entity1, entity2, relation, nodesize, fontsize, layout, title):
+# network plot - show relationship between different entities
+def network01(df, entity1, entity2, relation, nodesize, fontsize, layout):
     #   ## show all the relations
 
     #     demodata = {
@@ -1815,14 +1815,66 @@ def network01(df, entity1, entity2, relation, nodesize, fontsize, layout, title)
 
     nx.draw(G, with_labels=True, node_color='skyblue', alpha=1, node_size=nodesize, edge_cmap=plt.cm.Blues, pos=pos)
     nx.draw_networkx_edge_labels(G, pos=pos, edge_labels=labels_info, font_color='blue', font_size=fontsize)
-    plt.title(title)
+    # plt.title(title)
     plt.show()
 
     return
 
 
+# network plot02 - interactive plot show networks of different entities
+def network02(df, entity1, entity2, relation):
+    import networkx as nx
+    import matplotlib.pyplot as plt
+    from pyvis.network import Network
 
-this_is_nothing = 'Below modules are not validated. update:1/1---------------------👇'
+    # demodata = {
+    #     'entity1': ['A', 'E', 'A', 'A', 'C', 'B', 'E', 'E', 'E', 'B', 'D', 'I', 'G', 'E'],
+    #     'entity2': ['B', 'D', 'E', 'F', 'F', 'F', 'G', 'H', 'I', 'C', 'H', 'H', 'I', 'F'],
+    #     'relation': [
+    #         'Corr ?', 'Corr ?', 'Corr ?', 'Corr ?', 'Corr ?', 'Corr ?',
+    #         'Corr ?', 'Corr ?', 'Corr ?', 'Corr ?', 'Corr ?', 'Corr ?',
+    #         'Corr ?', 'Corr ?',
+    #     ]
+    # }
+
+
+    got_net = Network(height="500px", width="500px", bgcolor="white", font_color="black", notebook=True, directed=True)
+    # got_net = Network(notebook=True, directed=True)
+
+    sources = df[entity1]
+    targets = df[entity2]
+    # weights = data_triple['weights']
+    relations = df[relation]
+
+    edge_data = zip(sources, targets, relations)
+
+    for e in edge_data:
+        src = e[0]
+        dst = e[1]
+        # w = e[2]
+        r = e[2]
+
+        got_net.add_node(src, src, title=src)
+        got_net.add_node(dst, dst, title=dst)
+        got_net.add_edge(src, dst, title=r)
+
+    neighbor_map = got_net.get_adj_list()
+
+    # add neighbor data to node hover data
+    for node in got_net.nodes:
+        node["title"] += " Neighbors:<br>" + "<br>".join(neighbor_map[node["id"]])
+    #    node["value"] = len(neighbor_map[node["id"]])
+
+    return got_net.show("KG_networks.html")
+
+
+
+
+
+
+
+
+this_is_nothing = 'Below modules are not validated.---------------------👇'
 
 
 
